@@ -3,7 +3,7 @@
 const fs = require('fs');
 const sysPath = require('path');
 const should = require('should');
-const sinon = require('sinon').sandbox.create();
+const sinon = require('sinon');
 const logDriver = require('log-driver');
 const index = require('..');
 
